@@ -184,7 +184,7 @@ int update_shape(b2nd_array_t *array, int8_t ndim, const int64_t *shape,
       array->shape[i] = shape[i];
       array->chunkshape[i] = chunkshape[i];
       array->blockshape[i] = blockshape[i];
-      if (shape[i] != 0) {
+      if (array->chunkshape[i] != 0) {
         if (shape[i] % array->chunkshape[i] == 0) {
           array->extshape[i] = shape[i];
         } else {
@@ -616,6 +616,11 @@ int b2nd_get_slice_nchunks(const b2nd_array_t *array, const int64_t *start, cons
 
   int8_t ndim = array->ndim;
 
+  if (array->nitems == 0){  
+    *chunks_idx = NULL;
+    return 0;
+  }
+
   // 0-dim case
   if (ndim == 0) {
     *chunks_idx = malloc(1 * sizeof(int64_t));
@@ -758,6 +763,11 @@ int get_set_slice(void *buffer, int64_t buffersize, const int64_t *start, const
 
   uint8_t *buffer_b = buffer;
   int8_t ndim = array->ndim;
+  if (!set_slice) {
+    // get_slice paths may touch only a subset of the destination buffer.
+    // Pre-initialize so unread regions are defined and deterministic.
+    memset(buffer_b, 0, (size_t)buffersize);
+  }
 
   // 0-dim case
   if (ndim == 0) {
