@@ -339,6 +339,11 @@ blosc2_schunk* blosc2_schunk_open_offset_udio(const char* urlpath, int64_t offse
     return NULL;
   }
   blosc2_schunk* schunk = frame_to_schunk(frame, false, udio);
+  if (schunk == NULL) {
+    frame_free(frame);
+    BLOSC_TRACE_ERROR("Error converting frame to super-chunk");
+    return NULL;
+  }
 
   // Set the storage with proper defaults
   size_t pathlen = strlen(urlpath);
@@ -1388,7 +1393,10 @@ int blosc2_schunk_set_slice_buffer(blosc2_schunk *schunk, int64_t start, int64_t
 
 int schunk_get_slice_nchunks(blosc2_schunk *schunk, int64_t start, int64_t stop, int64_t **chunks_idx) {
   BLOSC_ERROR_NULL(schunk, BLOSC2_ERROR_NULL_POINTER);
-
+  if (schunk->nchunks == 0){  
+    *chunks_idx = NULL;
+    return 0;
+  }
   int64_t byte_start = start * schunk->typesize;
   int64_t byte_stop = stop * schunk->typesize;
   int64_t nchunk_start = byte_start / schunk->chunksize;
@@ -1733,7 +1741,10 @@ int blosc2_vlmeta_delete(blosc2_schunk *schunk, const char *name) {
   for (int i = nvlmetalayer; i < (schunk->nvlmetalayers - 1); i++) {
     schunk->vlmetalayers[i] = schunk->vlmetalayers[i + 1];
   }
+  schunk->vlmetalayers[schunk->nvlmetalayers - 1] = NULL;
+  free(vlmetalayer->name);
   free(vlmetalayer->content);
+  free(vlmetalayer);
   schunk->nvlmetalayers--;
 
   // Propagate to frames
